@@ -7,14 +7,13 @@ class GpuCpuBench:
     def __init__(self):
         self.names = {'gpucpu'}
         
-    def build(self, executor, deterministic):
+    def build(self, executor):
         basedir = os.path.dirname(os.path.abspath(__file__))
         'Builds the gpu benchmark'
         executor.local('/usr/local/cuda-10.1/bin/nvcc -arch=sm_70 %s/m.cu -o /tmp/bin/gpu' % basedir)
-        if deterministic:
-            params = {'gpucpu':[(r/100) for r in range(75, 126, 50)]}
-        else:
-            params = {'gpucpu':[lambda: (random.randint(75, 125)/100)]}
+
+        params = {'gpucpu':[(r/100) for r in range(75, 126, 50)]}
+
         return params
 
     def run(self, bench, params, executor):
