@@ -9,7 +9,7 @@ The parameter is the number of memory intensive processes started'''
         self.names = {'mem'}
         self.param_func = param_func
 
-    def build(self, executor, deterministic):
+    def build(self, executor):
         'Builds memory benchmark'
         nb_processes = executor.nbcores // executor.nbhosts
         if 'OAR_NODE_FILE' in os.environ:
@@ -19,13 +19,12 @@ The parameter is the number of memory intensive processes started'''
         executor.local('gcc -DNTIMES=2000 -O %s/mem.c -o /tmp/bin/mem' % basedir)
         #params = {'mem':list(range(1,2*nbproc+1))}
         #params = {'mem':list(range(1,4))}
-        if deterministic:
-            if self.param_func is None:
-                params = {'mem': [1, nb_processes]}
-            else:
-                params = {'mem' : self.param_func(nb_processes)}
+
+        if self.param_func is None:
+            params = {'mem': [1, nb_processes]}
         else:
-            params = {'mem': [lambda: random.randint(1, nb_processes)]}
+            params = {'mem' : self.param_func(nb_processes)}
+
         return params
 
     def run(self, bench, params, executor):
